==> SCENARIdemoServer_4.0.6.01_lin_x86_64_fr-FR.tgz: bin/scServer/nodejslib/scLiveCollab/MessagesHandler.js <==
/*
 * LICENCE[[
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1/CeCILL 2.O 
 *
 * The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at http://www.mozilla.org/MPL/ 
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, 
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License 
 * for the specific language governing rights and limitations under the 
 * License. 
 * 
 * The Original Code is utc.fr code. 
 * 
 * The Initial Developer of the Original Code is 
 * david.rivron@utc.fr
 * 
 * Portions created by the Initial Developer are Copyright (C) 2012
 * the Initial Developer. All Rights Reserved. 
 * 
 * Contributor(s): 
 * 
 * 
 * Alternatively, the contents of this file may be used under the terms of 
 * either of the GNU General Public License Version 2 or later (the "GPL"), 
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"), 
 * or the CeCILL Licence Version 2.0 (http://www.cecill.info/licences.en.html), 
 * in which case the provisions of the GPL, the LGPL or the CeCILL are applicable 
 * instead of those above. If you wish to allow use of your version of this file 
 * only under the terms of either the GPL or the LGPL, and not to allow others 
 * to use your version of this file under the terms of the MPL, indicate your 
 * decision by deleting the provisions above and replace them with the notice 
 * and other provisions required by the GPL or the LGPL. If you do not delete 
 * the provisions above, a recipient may use your version of this file under 
 * the terms of any one of the MPL, the GPL, the LGPL or the CeCILL.
 * ]]LICENCE
 */
 
 /**
 * Handler de message de base
 * 
 * S'occupe de filtrer les events provenant du serveur et fournit une interface
 */
 
var MessagesHandler = module.exports = function (pName, pCollabServer) {
	this.server = pCollabServer;
	
	pCollabServer.on('init', function(pClient, pMessage) {
		try {
			this.onInit(pClient, pMessage);
		} catch (e) {
			console.error(pName + '.onInit error:', e);
		}
	}.bind(this));
	
	pCollabServer.on('message', function (pClient, pMessage) {
		try {
			if (pMessage.type == pName) this.onMessage(pClient, pMessage);
		} catch (e) {
			console.error(pName + '.onMessage error:', e);
		}
	}.bind(this));
	
	pCollabServer.on('close', function(pClient) {
		try {
			this.onClose(pClient);
		} catch (e) {
			console.error(pName + '.onClose error:', e);
		}
	
	}.bind(this));
	
	pCollabServer.on('noPerm', function(pClient, pWspCd) {
		try {
			this.onNoPerm(pClient, pWspCd);
		} catch (e) {
			console.error(pName + '.onNoPerm error:', e);
		}
	
	}.bind(this));
	
}

MessagesHandler.OBSERVE_PERM = 'dialog.liveCollab#Observe';
MessagesHandler.DIALOG_PERM = 'dialog.liveCollab#Dialog';
MessagesHandler.ADMIN_PERM = 'dialog.liveCollab#Admin';

MessagesHandler.prototype = {
	onInit: function (pClient, pData) { },
	
	onMessage: function (pClient, pMessage) { },
	
	onClose: function (pClient) { },
	
	onNoPerm: function (pClient, pWspCd) { }
}

==> SCENARIdemoServer_4.1.0.11_lin_x86_64_fr-FR.tgz: bin/scServer/nodejslib/scLiveCollab/MessagesHandler.js <==
/*
 * LICENCE[[
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1/CeCILL 2.O 
 *
 * The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at http://www.mozilla.org/MPL/ 
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, 
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License 
 * for the specific language governing rights and limitations under the 
 * License. 
 * 
 * The Original Code is utc.fr code. 
 * 
 * The Initial Developer of the Original Code is 
 * david.rivron@utc.fr
 * 
 * Portions created by the Initial Developer are Copyright (C) 2012
 * the Initial Developer. All Rights Reserved. 
 * 
 * Contributor(s): 
 * 
 * 
 * Alternatively, the contents of this file may be used under the terms of 
 * either of the GNU General Public License Version 2 or later (the "GPL"), 
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"), 
 * or the CeCILL Licence Version 2.0 (http://www.cecill.info/licences.en.html), 
 * in which case the provisions of the GPL, the LGPL or the CeCILL are applicable 
 * instead of those above. If you wish to allow use of your version of this file 
 * only under the terms of either the GPL or the LGPL, and not to allow others 
 * to use your version of this file under the terms of the MPL, indicate your 
 * decision by deleting the provisions above and replace them with the notice 
 * and other provisions required by the GPL or the LGPL. If you do not delete 
 * the provisions above, a recipient may use your version of this file under 
 * the terms of any one of the MPL, the GPL, the LGPL or the CeCILL.
 * ]]LICENCE
 */
 
 /**
 * Handler de message de base
 * 
 * S'occupe de filtrer les events provenant du serveur et fournit une interface
 */
 
var MessagesHandler = module.exports = function (pName, pCollabServer) {
	this.server = pCollabServer;
	
	pCollabServer.on('init', function(pClient, pMessage) {
		try {
			this.onInit(pClient, pMessage);
		} catch (e) {
			console.error(pName + '.onInit error:', e);
		}
	}.bind(this));
	
	pCollabServer.on('message', function (pClient, pMessage) {
		try {
			if (pMessage.type == pName) this.onMessage(pClient, pMessage);
		} catch (e) {
			console.error(pName + '.onMessage error:', e);
		}
	}.bind(this));
	
	pCollabServer.on('close', function(pClient) {
		try {
			this.onClose(pClient);
		} catch (e) {
			console.error(pName + '.onClose error:', e);
		}
	
	}.bind(this));
	
	pCollabServer.on('noPerm', function(pClient, pWspCd) {
		try {
			this.onNoPerm(pClient, pWspCd);
		} catch (e) {
			console.error(pName + '.onNoPerm error:', e);
		}
	
	}.bind(this));
	
}

MessagesHandler.OBSERVE_PERM = 'server.liveCollab#observe';
MessagesHandler.DIALOG_PERM = 'server.liveCollab#dialog';
MessagesHandler.ADMIN_PERM = 'server.liveCollab#admin';
MessagesHandler.ADMINWSP_PERM = 'server.liveCollab#admin.wsp';

MessagesHandler.prototype = {
	onInit: function (pClient, pData) { },
	
	onMessage: function (pClient, pMessage) { },
	
	onClose: function (pClient) { },
	
	onNoPerm: function (pClient, pWspCd) { }
}
